@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::IDOPEREL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.3';
+  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.4';
 }
 
 use Moose;
@@ -22,6 +22,7 @@ use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::ReadmeFromPod;
 use Dist::Zilla::Plugin::CheckChangesHasContent;
 use Dist::Zilla::Plugin::DistManifestTests;
+use Dist::Zilla::Plugin::LatestPrereqs;
 
 =head1 NAME
 
@@ -29,7 +30,7 @@ Dist::Zilla::PluginBundle::IDOPEREL - IDOPEREL's plugin bundle for Dist::Zilla.
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
@@ -59,6 +60,7 @@ This bundle provides the following plugins and bundles:
 	[NextRelease]
 	[ReadmeFromPod]
 	[TestRelease]
+	[LatestPrereqs]
 
 =head1 INTERNAL METHODS
 
@@ -94,6 +96,7 @@ sub bundle_config {
 		[ CheckChangesHasContent	=> {} ],
 		[ DistManifestTests		=> {} ],
 		[ TestRelease			=> {} ],
+		[ LatestPrereqs			=> {} ],
 	);
 
 	push (@plugins, @extra);
